@@ -1,8 +1,8 @@
-/** 
+/**
  * \file files.c
  * Example program that lists all files on a device.
  *
- * Copyright (C) 2005-2007 Linus Walleij <triad@df.lth.se>
+ * Copyright (C) 2005-2011 Linus Walleij <triad@df.lth.se>
  * Copyright (C) 2007 Ted Bullock <tbullock@canada.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -21,6 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 #include "common.h"
+#include <stdlib.h>
 
 static void dump_fileinfo(LIBMTP_file_t *file)
 {
@@ -35,10 +36,13 @@ static void dump_fileinfo(LIBMTP_file_t *file)
 #ifdef __WIN32__
     printf("   File size %llu (0x%016I64X) bytes\n", file->filesize, file->filesize);
 #else
-    printf("   File size %llu (0x%016llX) bytes\n", file->filesize, file->filesize);
+    printf("   File size %llu (0x%016llX) bytes\n",
+	   (long long unsigned int) file->filesize,
+	   (long long unsigned int) file->filesize);
 #endif
   }
   printf("   Parent ID: %u\n", file->parent_id);
+  printf("   Storage ID: 0x%08X\n", file->storage_id);
   printf("   Filetype: %s\n", LIBMTP_Get_Filetype_Description(file->filetype));
 }
 
@@ -62,7 +66,7 @@ int main (int argc, char **argv)
   case LIBMTP_ERROR_MEMORY_ALLOCATION:
     fprintf(stderr, "mtp-files: Memory Allocation Error. Exit\n");
     return 1;
- 
+
   /* Unknown general errors - This should never execute */
   case LIBMTP_ERROR_GENERAL:
   default:
@@ -75,13 +79,12 @@ int main (int argc, char **argv)
     fprintf(stdout, "mtp-files: Successfully connected\n");
     fflush(stdout);
   }
-  
+
   /* iterate through connected MTP devices */
   for(iter = device_list; iter != NULL; iter = iter->next)
   {
-  	
     char *friendlyname;
-    
+
     /* Echo the friendly name so we know which device we are working with */
     friendlyname = LIBMTP_Get_Friendlyname(iter);
     if (friendlyname == NULL) {
@@ -90,7 +93,7 @@ int main (int argc, char **argv)
       printf("Listing File Information on Device with name: %s\n", friendlyname);
       free(friendlyname);
     }
-  
+
 	  /* Get track listing. */
 	  files = LIBMTP_Get_Filelisting_With_Callback(iter, NULL, NULL);
 	  if (files == NULL) {
@@ -108,9 +111,8 @@ int main (int argc, char **argv)
       }
 	  }
   }
-    
+
   LIBMTP_Release_Device_List(device_list);
   printf("OK.\n");
   exit (0);
 }
-
