@@ -49,14 +49,23 @@
 #define USB_CLASS_PTP 6
 #endif
 
-/* Default USB timeout length.  This can be overridden as needed
- * but should start with a reasonable value so most common 
+/*
+ * Default USB timeout length.  This can be overridden as needed
+ * but should start with a reasonable value so most common
  * requests can be completed.  The original value of 4000 was
  * not long enough for large file transfer.  Also, players can
  * spend a bit of time collecting data.  Higher values also
  * make connecting/disconnecting more reliable.
  */
-#define USB_TIMEOUT_DEFAULT     10000
+#define USB_TIMEOUT_DEFAULT     20000
+#define USB_TIMEOUT_LONG        60000
+static inline int get_timeout(PTP_USB* ptp_usb)
+{
+  if (FLAG_LONG_TIMEOUT(ptp_usb)) {
+    return USB_TIMEOUT_LONG;
+  }
+  return USB_TIMEOUT_DEFAULT;
+}
 
 /* USB control message data phase direction */
 #ifndef USB_DP_HTD
@@ -240,6 +249,7 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
   if (!(dev->descriptor.bDeviceClass == USB_CLASS_PER_INTERFACE ||
 	dev->descriptor.bDeviceClass == USB_CLASS_COMM ||
 	dev->descriptor.bDeviceClass == USB_CLASS_PTP ||
+	dev->descriptor.bDeviceClass == 0xEF ||	/* Intf. Association Desc.*/
 	dev->descriptor.bDeviceClass == USB_CLASS_VENDOR_SPEC)) {
     return 0;
   }
@@ -274,6 +284,13 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
 	  struct usb_interface_descriptor *intf =
 	    &dev->config[i].interface[j].altsetting[k];
 
+	  /*
+	   * MTP interfaces have three endpoints, two bulk and one
+	   * interrupt. Don't probe anything else.
+	   */
+	  if (intf->bNumEndpoints != 3)
+	    continue;
+
 	  /*
 	   * We only want to probe for the OS descriptor if the
 	   * device is USB_CLASS_VENDOR_SPEC or one of the interfaces
@@ -325,7 +342,7 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
             usb_close(devh);
             return 1;
           }
-  #ifdef LIBUSB_HAS_GET_DRIVER_NP
+#ifdef LIBUSB_HAS_GET_DRIVER_NP
 	  {
 	    /*
 	     * Specifically avoid probing anything else than USB mass storage devices
@@ -343,7 +360,7 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
 	      return 0;
 	    }
 	  }
-  #endif
+#endif
         }
       }
     }
@@ -846,7 +863,11 @@ ptp_read_func (
 
     LIBMTP_USB_DEBUG("Reading in 0x%04lx bytes\n", toread);
 
-    result = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, (char*)bytes, toread, ptp_usb->timeout);
+    result = USB_BULK_READ(ptp_usb->handle,
+			   ptp_usb->inep,
+			   (char*) bytes,
+			   toread,
+			   ptp_usb->timeout);
 
     LIBMTP_USB_DEBUG("Result of read: 0x%04x\n", result);
 
@@ -909,7 +930,11 @@ ptp_read_func (
     LIBMTP_USB_DEBUG("<==USB IN\n");
     LIBMTP_USB_DEBUG("Zero Read\n");
 
-    zeroresult = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, &temp, 0, ptp_usb->timeout);
+    zeroresult = USB_BULK_READ(ptp_usb->handle,
+			       ptp_usb->inep,
+			       &temp,
+			       0,
+			       ptp_usb->timeout);
     if (zeroresult != 0)
       LIBMTP_INFO("LIBMTP panic: unable to read in zero packet, response 0x%04x", zeroresult);
   }
@@ -950,7 +975,11 @@ ptp_write_func (
     if (getfunc_ret != PTP_RC_OK)
       return getfunc_ret;
     while (usbwritten < towrite) {
-	    result = USB_BULK_WRITE(ptp_usb->handle,ptp_usb->outep,((char*)bytes+usbwritten),towrite-usbwritten,ptp_usb->timeout);
+	    result = USB_BULK_WRITE(ptp_usb->handle,
+				    ptp_usb->outep,
+				    ((char*) bytes+usbwritten),
+				    towrite-usbwritten,
+				    ptp_usb->timeout);
 
 	    LIBMTP_USB_DEBUG("USB OUT==>\n");
 	    LIBMTP_USB_DATA(bytes+usbwritten, result, 16);
@@ -996,7 +1025,11 @@ ptp_write_func (
       LIBMTP_USB_DEBUG("USB OUT==>\n");
       LIBMTP_USB_DEBUG("Zero Write\n");
 
-      result=USB_BULK_WRITE(ptp_usb->handle,ptp_usb->outep,(char *)"x",0,ptp_usb->timeout);
+      result=USB_BULK_WRITE(ptp_usb->handle,
+			    ptp_usb->outep,
+			    (char *) "x",
+			    0,
+			    ptp_usb->timeout);
     }
   }
 
@@ -1377,7 +1410,11 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 		  // need to read in extra byte and discard it
 		  int result = 0;
 		  char byte = 0;
-                  result = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, &byte, 1, ptp_usb->timeout);
+                  result = USB_BULK_READ(ptp_usb->handle,
+					 ptp_usb->inep,
+					 &byte,
+					 1,
+					 ptp_usb->timeout);
 
 		  if (result != 1)
 		    LIBMTP_INFO("Could not read in extra byte for PTP_USB_BULK_HS_MAX_PACKET_LEN_READ long file, return value 0x%04x\n", result);
@@ -1388,7 +1425,11 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 
 		  LIBMTP_INFO("Reading in zero packet after header\n");
 
-		  zeroresult = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, &zerobyte, 0, ptp_usb->timeout);
+		  zeroresult = USB_BULK_READ(ptp_usb->handle,
+					     ptp_usb->inep,
+					     &zerobyte,
+					     0,
+					     ptp_usb->timeout);
 
 		  if (zeroresult != 0)
 		    LIBMTP_INFO("LIBMTP panic: unable to read in zero packet, response 0x%04x", zeroresult);
@@ -1497,15 +1538,31 @@ ptp_usb_event (PTPParams* params, PTPContainer* event, int wait)
 	ret = PTP_RC_OK;
 	switch(wait) {
 	case PTP_EVENT_CHECK:
-                result=USB_BULK_READ(ptp_usb->handle, ptp_usb->intep,(char *)&usbevent,sizeof(usbevent),ptp_usb->timeout);
+                result=USB_BULK_READ(ptp_usb->handle,
+				     ptp_usb->intep,
+				     (char *) &usbevent,
+				     sizeof(usbevent),
+				     0);
 		if (result==0)
-                        result = USB_BULK_READ(ptp_usb->handle, ptp_usb->intep,(char *) &usbevent, sizeof(usbevent), ptp_usb->timeout);
+		  result = USB_BULK_READ(ptp_usb->handle,
+					 ptp_usb->intep,
+					 (char *) &usbevent,
+					 sizeof(usbevent),
+					 0);
 		if (result < 0) ret = PTP_ERROR_IO;
 		break;
 	case PTP_EVENT_CHECK_FAST:
-                result=USB_BULK_READ(ptp_usb->handle, ptp_usb->intep,(char *)&usbevent,sizeof(usbevent),ptp_usb->timeout);
+                result=USB_BULK_READ(ptp_usb->handle,
+				     ptp_usb->intep,
+				     (char *) &usbevent,
+				     sizeof(usbevent),
+				     ptp_usb->timeout);
 		if (result==0)
-                        result = USB_BULK_READ(ptp_usb->handle, ptp_usb->intep,(char *) &usbevent, sizeof(usbevent), ptp_usb->timeout);
+		  result = USB_BULK_READ(ptp_usb->handle,
+					 ptp_usb->intep,
+					 (char *) &usbevent,
+					 sizeof(usbevent),
+					 ptp_usb->timeout);
 		if (result < 0) ret = PTP_ERROR_IO;
 		break;
 	default:
@@ -1556,7 +1613,10 @@ ptp_usb_control_cancel_request (PTPParams *params, uint32_t transactionid) {
 	htod32a(&buffer[2],transactionid);
 	ret = usb_control_msg(ptp_usb->handle,
 			      USB_TYPE_CLASS | USB_RECIP_INTERFACE,
-                              0x64, 0x0000, 0x0000, (char *) buffer, sizeof(buffer), ptp_usb->timeout);
+                              0x64, 0x0000, 0x0000,
+			      (char *) buffer,
+			      sizeof(buffer),
+			      ptp_usb->timeout);
 	if (ret < sizeof(buffer))
 		return PTP_ERROR_IO;
 	return PTP_RC_OK;
@@ -1581,98 +1641,97 @@ static int init_ptp_usb (PTPParams* params, PTP_USB* ptp_usb, struct usb_device*
    */
   params->byteorder = PTP_DL_LE;
 
-  ptp_usb->timeout = USB_TIMEOUT_DEFAULT;
+  ptp_usb->timeout = get_timeout(ptp_usb);
 
-  if ((device_handle = usb_open(dev))){
-    if (!device_handle) {
-      perror("usb_open()");
-      return -1;
-    }
-    ptp_usb->handle = device_handle;
+  device_handle = usb_open(dev);
+  if (!device_handle) {
+    perror("usb_open()");
+    return -1;
+  }
+  ptp_usb->handle = device_handle;
 #ifdef LIBUSB_HAS_DETACH_KERNEL_DRIVER_NP
-    /*
-     * If this device is known to be wrongfully claimed by other kernel
-     * drivers (such as mass storage), then try to unload it to make it
-     * accessible from user space.
-     */
-    if (FLAG_UNLOAD_DRIVER(ptp_usb)) {
-      if (usb_get_driver_np(device_handle, (int) ptp_usb->interface,
-			    buf, sizeof(buf)) == 0) {
-	if (usb_detach_kernel_driver_np(device_handle,
-					(int) ptp_usb->interface)) {
-	  perror("usb_detach_kernel_driver_np()");
-	  return -1;
-        }
+  /*
+   * If this device is known to be wrongfully claimed by other kernel
+   * drivers (such as mass storage), then try to unload it to make it
+   * accessible from user space.
+   */
+  if (FLAG_UNLOAD_DRIVER(ptp_usb)) {
+    if (usb_get_driver_np(device_handle, (int) ptp_usb->interface,
+                          buf, sizeof(buf)) == 0) {
+      if (usb_detach_kernel_driver_np(device_handle,
+                                      (int) ptp_usb->interface)) {
+        perror("usb_detach_kernel_driver_np()");
+        return -1;
       }
     }
+  }
 #endif
 #ifdef __WIN32__
-    // Only needed on Windows, and cause problems on other platforms.
-    if (usb_set_configuration(device_handle, dev->config->bConfigurationValue)) {
-      perror("usb_set_configuration()");
-      return -1;
-    }
+  // Only needed on Windows, and cause problems on other platforms.
+  if (usb_set_configuration(device_handle, dev->config->bConfigurationValue)) {
+    perror("usb_set_configuration()");
+    return -1;
+  }
 #endif
-    // It seems like on kernel 2.6.31 if we already have it open on another
-    // pthread in our app, we'll get an error if we try to claim it again,
-    // but that error is harmless because our process already claimed the interface
-    usbresult = usb_claim_interface(device_handle, (int) ptp_usb->interface);
+  // It seems like on kernel 2.6.31 if we already have it open on another
+  // pthread in our app, we'll get an error if we try to claim it again,
+  // but that error is harmless because our process already claimed the interface
+  usbresult = usb_claim_interface(device_handle, (int) ptp_usb->interface);
 
-    if (usbresult != 0)
-      fprintf(stderr, "ignoring usb_claim_interface = %d", usbresult);
+  if (usbresult != 0)
+    fprintf(stderr, "ignoring usb_claim_interface = %d", usbresult);
 
-    // FIXME : Discovered in the Barry project
-    // kernels >= 2.6.28 don't set the interface the same way as
-    // previous versions did, and the Blackberry gets confused
-    // if it isn't explicitly set
-    // See above, same issue with pthreads means that if this fails it is not
-    // fatal
-    // However, this causes problems on Macs so disable here
-    #ifndef __APPLE__
-    usbresult = usb_set_altinterface(device_handle, 0);
-    if (usbresult)
-      fprintf(stderr, "ignoring usb_claim_interface = %d", usbresult);
-    #endif
+  // FIXME : Discovered in the Barry project
+  // kernels >= 2.6.28 don't set the interface the same way as
+  // previous versions did, and the Blackberry gets confused
+  // if it isn't explicitly set
+  // See above, same issue with pthreads means that if this fails it is not
+  // fatal
+  // However, this causes problems on Macs so disable here
+#ifndef __APPLE__
+  usbresult = usb_set_altinterface(device_handle, 0);
+  if (usbresult)
+    fprintf(stderr, "ignoring usb_claim_interface = %d", usbresult);
+#endif
 
-    if (FLAG_SWITCH_MODE_BLACKBERRY(ptp_usb)) {
-      int ret;
+  if (FLAG_SWITCH_MODE_BLACKBERRY(ptp_usb)) {
+    int ret;
 
-      // FIXME : Only for BlackBerry Storm
-      // What does it mean? Maybe switch mode...
-	  // This first control message is absolutely necessary
-      usleep(1000);
-      ret = usb_control_msg(device_handle,
-		      USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-		      0xaa, 0x00, 0x04, buf, 0x40, 1000);
-      LIBMTP_USB_DEBUG("BlackBerry magic part 1:\n");
-      LIBMTP_USB_DATA(buf, ret, 16);
+    // FIXME : Only for BlackBerry Storm
+    // What does it mean? Maybe switch mode...
+    // This first control message is absolutely necessary
+    usleep(1000);
+    ret = usb_control_msg(device_handle,
+                          USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                          0xaa, 0x00, 0x04, buf, 0x40, 1000);
+    LIBMTP_USB_DEBUG("BlackBerry magic part 1:\n");
+    LIBMTP_USB_DATA(buf, ret, 16);
 
-      usleep(1000);
-	  // This control message is unnecessary
-      ret = usb_control_msg(device_handle,
-		      USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-		      0xa5, 0x00, 0x01, buf, 0x02, 1000);
-      LIBMTP_USB_DEBUG("BlackBerry magic part 2:\n");
-      LIBMTP_USB_DATA(buf, ret, 16);
+    usleep(1000);
+    // This control message is unnecessary
+    ret = usb_control_msg(device_handle,
+                          USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                          0xa5, 0x00, 0x01, buf, 0x02, 1000);
+    LIBMTP_USB_DEBUG("BlackBerry magic part 2:\n");
+    LIBMTP_USB_DATA(buf, ret, 16);
 
-      usleep(1000);
-	  // This control message is unnecessary
-      ret = usb_control_msg(device_handle,
-		      USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-		      0xa8, 0x00, 0x01, buf, 0x05, 1000);
-      LIBMTP_USB_DEBUG("BlackBerry magic part 3:\n");
-      LIBMTP_USB_DATA(buf, ret, 16);
+    usleep(1000);
+    // This control message is unnecessary
+    ret = usb_control_msg(device_handle,
+                          USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                          0xa8, 0x00, 0x01, buf, 0x05, 1000);
+    LIBMTP_USB_DEBUG("BlackBerry magic part 3:\n");
+    LIBMTP_USB_DATA(buf, ret, 16);
 
-      usleep(1000);
-	  // This control message is unnecessary
-      ret = usb_control_msg(device_handle,
-		      USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-		      0xa8, 0x00, 0x01, buf, 0x11, 1000);
-      LIBMTP_USB_DEBUG("BlackBerry magic part 4:\n");
-      LIBMTP_USB_DATA(buf, ret, 16);
+    usleep(1000);
+    // This control message is unnecessary
+    ret = usb_control_msg(device_handle,
+                          USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                          0xa8, 0x00, 0x01, buf, 0x11, 1000);
+    LIBMTP_USB_DEBUG("BlackBerry magic part 4:\n");
+    LIBMTP_USB_DATA(buf, ret, 16);
 
-      usleep(1000);
-    }
+    usleep(1000);
   }
   return 0;
 }
@@ -1731,8 +1790,6 @@ static void clear_halt(PTP_USB* ptp_usb)
 
 static void close_usb(PTP_USB* ptp_usb)
 {
-  // Commented out since it was confusing some
-  // devices to do these things.
   if (!FLAG_NO_RELEASE_INTERFACE(ptp_usb)) {
     /*
      * Clear any stalled endpoints
@@ -1753,6 +1810,16 @@ static void close_usb(PTP_USB* ptp_usb)
     usb_resetep(ptp_usb->handle, ptp_usb->outep);
     usb_release_interface(ptp_usb->handle, (int) ptp_usb->interface);
   }
+  if (FLAG_FORCE_RESET_ON_CLOSE(ptp_usb)) {
+    /*
+     * Some devices really love to get reset after being
+     * disconnected. Again, since Windows never disconnects
+     * a device closing behaviour is seldom or never exercised
+     * on devices when engineered and often error prone.
+     * Reset may help some.
+     */
+    usb_reset(ptp_usb->handle);
+  }
   usb_close(ptp_usb->handle);
 }
 
@@ -1899,6 +1966,9 @@ LIBMTP_error_number_t configure_usb_device(LIBMTP_raw_device_t *device,
     return LIBMTP_ERROR_CONNECTING;
   }
 
+  /* Copy USB version number */
+  ptp_usb->bcdusb = libusb_device->descriptor.bcdUSB;
+
   /* Attempt to initialize this device */
   if (init_ptp_usb(params, ptp_usb, libusb_device) < 0) {
     LIBMTP_ERROR("LIBMTP PANIC: Unable to initialize device\n");
@@ -1911,10 +1981,9 @@ LIBMTP_error_number_t configure_usb_device(LIBMTP_raw_device_t *device,
    */
   if ((ret = ptp_opensession(params, 1)) == PTP_ERROR_IO) {
     LIBMTP_ERROR("PTP_ERROR_IO: failed to open session, trying again after resetting USB interface\n");
-    close_usb(ptp_usb);
-
     LIBMTP_ERROR("LIBMTP libusb: Attempt to reset device\n");
     usb_reset(ptp_usb->handle);
+    close_usb(ptp_usb);
 
     if(init_ptp_usb(params, ptp_usb, libusb_device) <0) {
       LIBMTP_ERROR("LIBMTP PANIC: Could not init USB on second attempt\n");
@@ -1959,24 +2028,63 @@ void close_device (PTP_USB *ptp_usb, PTPParams *params)
 
 void set_usb_device_timeout(PTP_USB *ptp_usb, int timeout)
 {
-    ptp_usb->timeout = timeout;
+  ptp_usb->timeout = timeout;
 }
 
 void get_usb_device_timeout(PTP_USB *ptp_usb, int *timeout)
 {
-    *timeout = ptp_usb->timeout;
+  *timeout = ptp_usb->timeout;
+}
+
+int guess_usb_speed(PTP_USB *ptp_usb)
+{
+  int bytes_per_second;
+
+  /*
+   * We don't know the actual speeds so these are rough guesses
+   * from the info you can find here:
+   * http://en.wikipedia.org/wiki/USB#Transfer_rates
+   * http://www.barefeats.com/usb2.html
+   */
+  switch (ptp_usb->bcdusb & 0xFF00) {
+  case 0x0100:
+    /* 1.x USB versions let's say 1MiB/s */
+    bytes_per_second = 1*1024*1024;
+    break;
+  case 0x0200:
+  case 0x0300:
+    /* USB 2.0 nominal speed 18MiB/s */
+    /* USB 3.0 won't be worse? */
+    bytes_per_second = 18*1024*1024;
+    break;
+  default:
+    /* Half-guess something? */
+    bytes_per_second = 1*1024*1024;
+    break;
+  }
+  return bytes_per_second;
 }
 
 static int usb_clear_stall_feature(PTP_USB* ptp_usb, int ep)
 {
   return (usb_control_msg(ptp_usb->handle,
-			  USB_RECIP_ENDPOINT, USB_REQ_CLEAR_FEATURE, USB_FEATURE_HALT,
-                          ep, NULL, 0, ptp_usb->timeout));
+			  USB_RECIP_ENDPOINT,
+			  USB_REQ_CLEAR_FEATURE,
+			  USB_FEATURE_HALT,
+                          ep,
+			  NULL,
+			  0,
+			  ptp_usb->timeout));
 }
 
 static int usb_get_endpoint_status(PTP_USB* ptp_usb, int ep, uint16_t* status)
 {
   return (usb_control_msg(ptp_usb->handle,
-			  USB_DP_DTH|USB_RECIP_ENDPOINT, USB_REQ_GET_STATUS,
-                          USB_FEATURE_HALT, ep, (char *)status, 2, ptp_usb->timeout));
+			  USB_DP_DTH|USB_RECIP_ENDPOINT,
+			  USB_REQ_GET_STATUS,
+                          USB_FEATURE_HALT,
+			  ep,
+			  (char *) status,
+			  2,
+			  ptp_usb->timeout));
 }
